#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# file      : Language_Init.py
# project   : basebuildpy
# copyright : (C) 2014 by Claude BULIN
#
# This file is part of basebuildpy project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA

from gi.repository import Gtk
import os, sys
import gettext, locale

class Translator:
	def __init__(self, project):
		self.project = project
		# Setup foreign language support
		langs = []
		lc, encoding = locale.getlocale(locale.LC_MESSAGES)
		if (lc):
			langs = [lc]
		# Add by xcfaudio: complementary xx from xx_XX
		if len(lc) == 5:
			str_lang = lc[0:2]
			if str_lang not in langs:
				langs.append( str_lang )
		language = os.environ.get("LANGUAGE", None)
		if (language):
			langs += language.split(":")
		# Set locale specific settings
		locale.setlocale(locale.LC_ALL)
		locale.bindtextdomain("basebuildpy", self.project.LOCALE_DIR)
		locale.bind_textdomain_codeset("basebuildpy", "UTF-8")
		# Set gettext settings
		gettext.bindtextdomain("basebuildpy", self.project.LOCALE_DIR)
		gettext.bind_textdomain_codeset("basebuildpy", "UTF-8")
		gettext.textdomain("basebuildpy")
		gettext.install(domain="basebuildpy", localedir=self.project.LOCALE_DIR)
		# This reference is used by other classes to define the _ method
		self.lang = gettext.translation("basebuildpy", self.project.LOCALE_DIR, languages = langs, fallback = True)
